;(function(){
  var map = {
  "commitId": "b965116af11fde2db28245622ec9b97ffc2cb90a",
  "branchName": "release-client-6.1.x",
  "buildTime": "2024-06-27 05:56:26 GMT",
  "buildVersion": "1.0.503",
  "css": [
    "@zoom/client-scheduler/static/css/chunk-vendors.f0f0dc24.css",
    "@zoom/client-scheduler/static/css/index.1f8c4026.css"
  ],
  "js": [
    "@zoom/client-scheduler/chunk-vendors.4061f47f68bdcc205e6c.js",
    "@zoom/client-scheduler/index.4061f47f68bdcc205e6c.js"
  ],
  "key": "clientSchedulerResource"
};
  var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
  map.css && map.css.forEach(function (cssItem) {
    var linkTag = document.createElement('link');
    var cssURL = prefix +  cssItem ;
    linkTag.href = cssURL;
    linkTag.setAttribute('rel','stylesheet');
    document.head.appendChild(linkTag);
  });
  map.js && map.js.forEach(function (jsItem) {
    var scriptTag = document.createElement("script");
    var jsURL = prefix +  jsItem;
    scriptTag.setAttribute("src", jsURL);
    document.body.appendChild(scriptTag);
  });
  window.domainFromServer= "https://dev-integration.zoomdev.us/fe-static/";
})();
